<?php

/*
 * Clase base para definir una conexin genrica a una BD desde PHP.
 * Se debern definir clases que hereden de sta redefiniendo sus mtodos
 * para cada SGBD distinto al que queramos acceder.
 *
 * Juanky Moral <jcarlos.moral@dgip.mir.es>
 *
 * 06/03/2001
 */


/**
 * CLASE ConexionGenerica
 *
 * Esta clase es una plantilla para definir la estructura bsica (variables
 * y mtodos) de todas las clases para conectar a distintas BBDD que ms
 * tarde heredarn de esta, redefiniendo los mtodos.
 */

class ConexionGenerica {

	 /* El enlace con la BD */
	 var $link;

	 /*
         * Constructor. No hace nada. Se podra quitar ...
	 */
	 function ConexionGenerica() {}


	 /*
	 * FUNCIN connect( servidor, usuario, clave )
         * Conecta con el servidor, identificndose como usuario y clave.
	 * No hace nada, ya que ser redefinida por las clases que hereden de esta.
	 */
	 function connect($servidor, $usuario, $clave) {
		echo "<h1>El mtodo <i>connect</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	 }


	/*
	 * FUNCIN close()
	 * Finaliza la conexion con el servidor.
	 * No hace nada, debe ser redefinida por las clases que hereden de esta.
	 */
	 function close() {
		echo "<h1>El mtodo <i>close</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}

	/**
	 * FUNCIN select_db( base_datos )
	 * Elige la base de datos con la que trabajar.
	 * No hace nada, puede ser redefinida por las clases que hereden de esta.
	 */
	function select_db($base_datos) {
		echo "<h1>El mtodo <i>select_db</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}

	/**
	 * FUNCIN query( query )
	 * Realiza una consulta o actualizacin en la BD.
	 * No hace nada, debe ser redefinida por las clases que hereden de esta.
	 */
	function query($query) {
		echo "<h1>El mtodo <i>query</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}

	/**
	 * FUNCIN fetch_array( resultado )
	 * Realiza una consulta o actualizacin en la BD.
	 * No hace nada, debe ser redefinida por las clases que hereden de esta.
	 */
	function fetch_array($resultado) {
		echo "<h1>El mtodo <i>query</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}

	/**
	 * FUNCIN free_result( resultado )
	 * Libera la memoria ocupada por un resultado.
	 * No hace nada, debe ser redefinida por las clases que hereden de esta.
	 */
	function free_result($resultado) {
		echo "<h1>El mtodo <i>free_result</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}

	/**
	 * FUNCIN num_rows( resultado )
	 * Devuelve el nmero de filas de un resultado.
	 * No hace nada, debe ser redefinida por las clases que hereden de esta.
	 */
	function num_rows($resultado) {
		echo "<h1>El mtodo <i>num_rows</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}

    /**
	 * FUNCIN rows_affected( resultado )
	 * Devuelve el nmero de filas afectadas por un Insert, Update o Delete.
	 * No hace nada, debe ser redefinida por las clases que hereden de esta.
	 */
	function rows_affected($resultado) {
		echo "<h1>El mtodo <i>rows_affected</i> no est " .
		     "implementado en la clase <i>" . get_class($this) . "</i></h1>";
		return FALSE;
	}
}

?>