<?php
/*****************************************************************************
 * This file contains some routines useful for form validation and string
 * checking:
 * - is_alpha()                     (by Tobias Radschiller)
 * - is_numeric()                   (by Tobias Radschiller)
 * - is_alphanumeric()              (by Tobias Radschiller)
 * - is_email()                     (by Tobias Radschiller)
 * - is_clean_text()                (by Tobias Radschiller)
 * - contains_bad_words()           (by Tobias Radschiller)
 * - contains_phone_number()        (by Tobias Radschiller)
 * - contiene_telefono() 			(by juanky)
 * - contains_dni() 				(by P.E.I.X. team)
 * - contains_nie(string string)    (by juanky)
 * - contiene_etiqueta() 			(by juanky)
 * - contains_nif() 				(by P.E.I.X. team)
 * - is_cp()        				(by P.E.I.X. team)
 * - letra_nif()    				(by P.E.I.X. team and J.A.A.G.)
 * - es_fecha()     				(by P.E.I.X. team)
 * - es_fecha_futura()				(by P.E.I.X. team)
 * - es_fecha_pasada()              (by P.E.I.X. team)
 * - trim_post()              		(by juanky)
 *****************************************************************************/

function _is_valid($string, $min_length, $max_length, $regex)
{
    // Check if the string is empty
    $str = trim($string);
    if(empty($str))
    {
        return(false);
    }

    // Does the string entirely consist of characters of $type?
    if(!eregi("^$regex$", $string))
    {
        return(false);
    }

    // Check for the optional length specifiers
    $strlen = strlen($string);
    if(($min_length != 0 && $strlen < $min_length) || ($max_length != 0 && $strlen > $max_length))
    {
        return(false);
    }

    // Passed all tests
    return(true);

}

/*
 *      bool is_alpha(string string[, int min_length[, int max_length]])
 *      Check if a string consists of alphabetic characters only. Optionally
 *      check if it has a minimum length of min_length characters and/or a
 *      maximum length of max_length characters.
 */
function is_alpha($string, $min_length = 0, $max_length = 0)
{
    $ret = _is_valid($string, $min_length, $max_length, "[[:alpha:]]+");

    return($ret);
}

/*
 *      bool is_a_number(string string[, int min_length[, int max_length]])
 *      Check if a string consists of digits only. Optionally
 *      check if it has a minimum length of min_length characters and/or a
 *      maximum length of max_length characters.
 */
function is_a_number($string, $min_length = 0, $max_length = 0)
{
    $ret = _is_valid($string, $min_length, $max_length, "[[:digit:]]+");

    return($ret);
}



/*
 *      bool is_alphanumeric(string string[, int min_length[, int max_length]])
 *      Check if a string consists of alphanumeric characters only. Optionally
 *      check if it has a minimum length of min_length characters and/or a
 *      maximum length of max_length characters.
 */
function is_alphanumeric($string, $min_length = 0, $max_length = 0)
{
    $ret = _is_valid($string, $min_length, $max_length, "[[:alnum:]]+");

    return($ret);
}

/*
 *      bool is_email(string string[, int min_length[, int max_length]])
 *      Check if a string is a syntactically valid mail address. Optionally
 *      check if it has a minimum length of min_length characters and/or a
 *      maximum length of max_length characters.
 */
function is_email($string)
{
    // Remove whitespace
    $string = trim($string);

    $ret = ereg(
                '^([a-z0-9_]|\\-|\\.)+'.
                '@'.
                '(([a-z0-9_]|\\-)+\\.)+'.
                '[a-z]{2,4}$',
                $string);

    return($ret);
}

/*
 *      bool is_clean_text(string string[, int min_length[, int max_length]])
 *      Check if a string contains only a subset of alphanumerics characters
 *      allowed in the Western alphabets. Useful for validation of names.
 *      Optionally check if it has a minimum length of min_length characters and/or a
 *      maximum length of max_length characters.
 */
function is_clean_text($string, $min_length = 0, $max_length = 0)
{
    $ret = _is_valid($string, $min_length, $max_length, "[a-zA-Z[:space:]`']+");

    return($ret);
}

/*
 *      bool contains_bad_words(string string)
 *      Check if a string contains bad words, as defined in the array below
 */
function contains_bad_words($string)
{
    // This array contains words which trigger the "meep" feature of this function
    // (ie. if one of the array elements is found in the string, the function will
    // return true). Please note that these words do not constitute a rating of their
    // meanings - they're used for a first indication if the string might contain
    // inapropiate language.
    $bad_words = array(
                    'anal',           'ass',        'bastard',
                    'bitch',          'blow',       'butt',
                    'cock',           'clit',       'cock',
                    'cornh',          'cum',        'cunnil',
                    'cunt',           'dago',       'defecat',
                    'dick',           'dildo',      'douche',
                    'erotic',         'fag',        'fart',
                    'felch',          'fellat',     'fuck',
                    'gay',            'genital',    'gosh',
                    'hate',           'homo',       'honkey',
                    'horny',          'jesus',      'jew',
                    'jiz',            'kike',       'kill',
                    'lesbian',        'masoc',      'masturba',
                    'nazi',           'nigger',     'nude',
                    'nudity',         'oral',       'pecker',
                    'penis',          'potty',      'pussy',
                    'rape',           'rimjob',     'satan',
                    'screw',          'semen',      'sex',
                    'shit',           'slut',       'snot',
                    'spew',           'suck',       'tit',
                    'twat',           'urinat',     'vagina',
                    'viag',           'vibrator',   'whore',
                    'xxx',			 'microsoft'
    );

    // Check for bad words
    for($i=0; $i<count($bad_words); $i++)
    {
        if(strstr(strtoupper($string), strtoupper($bad_words[$i])))
        {
            return(true);
        }
    }

    // Passed the test
    return(false);
}

/*
 *      bool contains_phone_number(string string)
 *      Check if a string contains a phone number (any 10+-digit sequence,
 *      optionally separated by "(", " ", "-" or "/").
 */
function contains_phone_number($string)
{
     // Check for phone number
     if(ereg("[[:digit:]]{3,10}[\. /\)\(-]*[[:digit:]]{6,10}", $string))
     {
        return(true);
     }

     // Passed the test
     return(false);
}

function contiene_telefono($string){
	if(ereg("[[:digit:]]{4,9}",$string)){
		return true;
	}
	return false;
}

/* $Id: String_Validation.php,v 1.2 2003/05/26 10:39:58 cheto Exp $ */




/* P.E.I.X. functions */

/*
 *	bool is_cp(string string)
 *	Check if a string is a valid cp (codigo postal)
 */

function is_cp($string) {
	// Check for cp number
	if(!is_a_number($string) or $string < 1000 or $string > 52999) {
		return(false);
	}
	return(true);
}


/*
 *	bool contains_dni(string string)
 *	Check if a string contains a DNI number
 *	(any 6+ digit sequence, followed by a trailing nif-alpha)
 */

function contains_dni($string) {
	// Check for dni number
	if(ereg('^([0-9]){6,8}'.'([A-Za-z]){1}$', $string)) {
		return(true);
	}
	return(false);
}

/*
 *	bool contains_nie(string string)
 *	Check if a string contains a NIE number
 *  (nmero de identificacin de extranjero)
 *	(A 'X' char followed by any 7 digit sequence, followed by a trailing alpha)
 */
function contains_nie ($string) {
    // Check for nie number
    if(ereg('^([xX]){1}'.'([[:digit:]]){7}'.'([A-Za-z]){1}$', $string)){
        return (true);
    }
    return (false);
}

function contiene_etiqueta($string) {
	// Comprueba si es una etiqueta de ordenador vlida
	if(ereg('^([xXtT]){1}'.'([-]){1}'.'([[:digit:]]){5}'.'([-]){1}'.'([[:digit:]]){2}$', $string)){
		return(true);
	}
	return(false);
}


/*
 *	bool contains_cif(string string)
 *	Check if a string contains a CIF number
 *	(any 7+ digit sequence, with a lead or trailing char)
 */

function contains_cif($string) {
	// Check for cif number
	if(ereg('^([A-Z])?'.'([0-9]){7,8}'.'([A-Z])?$', $string)) {
		return(true);
	}	return(false);
}

function validate_nif($number){
	if( ereg('^([0-9]){6,8}'.'([a-zA-Z]){1}$',$number) ) {
		$trail_char = strtoupper(substr($number, -1));
		$dni = ereg_replace("([a-zA-Z]){1}","",$number);
		$letra = letra_nif($dni);
		if($letra == $trail_char) {
			$nif = $dni . $letra;
		} else {
			$nif = "";
		}
		return $nif;
	}
	$nif = $number . letra_nif($number);
	return $nif;
}



/*
 *	string letra_nif(string string)
 *	Computes a DNI number and returns de properly trailing nif char
 *	
 */

function letra_nif($number) {
	$hash_value = $number - ((int)($number / 23) * 23);
	switch ($hash_value) {
		case 0:
			$letra = 'T';
			break;
		case 1:
			$letra = 'R';
			break;
		case 2:
			$letra = 'W';
			break;
		case 3:
			$letra = 'A';
			break;
		case 4:
			$letra = 'G';
			break;
		case 5:
			$letra = 'M';
			break;
		case 6:
			$letra = 'Y';
			break;
		case 7:
			$letra = 'F';
			break;
		case 8:
			$letra = 'P';
			break;
		case 9:
			$letra = 'D';
			break;
		case 10:
			$letra = 'X';
			break;
		case 11:
			$letra = 'B';
			break;
		case 12:
			$letra = 'N';
			break;
		case 13:
			$letra = 'J';
			break;
		case 14:
			$letra = 'Z';
			break;
		case 15:
			$letra = 'S';
			break;
		case 16:
			$letra = 'Q';
			break;
		case 17:
			$letra = 'V';
			break;
		case 18:
			$letra = 'H';
			break;
		case 19:
			$letra = 'L';
			break;
		case 20:
			$letra = 'C';
			break;
		case 21:
			$letra = 'K';
			break;
		case 22:
			$letra = 'E';
			break;
		case 23:
			$letra = 'U';
			break;
		default:
			$letra = '';
			break;
	} 
	
	return ($letra);
}


/*
 *      string es_fecha(string string string)
 *      Comprueba si los parmetros entrados son una fecha real
 */
function es_fecha($dia,$mes,$anyo){
	$fecha = checkdate($mes,$dia,$anyo) ?  "$dia-$mes-$anyo" : "";   
	return ($fecha);	
}



/*
 *      string es_fecha_futura(string string string)
 *      Comprueba si una fecha real es mayor que la fecha actual
 */
function es_fecha_futura($dia,$mes,$anyo){
	// obtenemos la fecha actal
	$dia_ahora=date(d);
    $mes_ahora=date(m);
    $anyo_ahora=date(Y);
    //validacin fisica
	$fecha = checkdate($mes,$dia,$anyo) ?  "$dia-$mes-$anyo" : "";   
    //validacin lgica
	if($fecha){
    	if ( mktime(0,0,0,$mes,$dia,$anyo) > mktime(0,0,0,$mes_ahora,$dia_ahora,$anyo_ahora) ){
    		return ($fecha);
		}else{
			return (false);
    	}
	}
}

/*
 *      string es_fecha_pasada(string string string)
 *      Comprueba si una fecha real es menor o igual que la fecha actual
 */
function es_fecha_pasada($dia,$mes,$anyo){


    //validacin fisica
	$fecha = checkdate($mes,$dia,$anyo) ?  "$dia/$mes/$anyo" : "";   
    //validacin lgica
	if($fecha){
    	if ( mktime(0,0,0,$mes,$dia,$anyo) <= time() ){
    		return ($fecha);
		}else{
			
			return (false);
    	}
	}
}

function trim_post($form_array){
// hace trim sobre los datos enviados con el mtodo POST
while(list($key,$value)=each($_POST[$form_array])){
		$_POST['form'][$key]=trim($value);
	}
return;
}

?>
